summaryrefslogtreecommitdiff
path: root/src/ipcpd/ipcp.c
diff options
context:
space:
mode:
authorSander Vrijders <sander.vrijders@intec.ugent.be>2016-06-28 16:38:03 +0200
committerSander Vrijders <sander.vrijders@intec.ugent.be>2016-06-28 16:45:45 +0200
commit99d19307fae8f1370f52a62aee88fded624ad464 (patch)
tree36b94730d8690c2d131f39b3cc3ff715674f9fcc /src/ipcpd/ipcp.c
parent0d789ed8d938cc342c8f2138280795a1d5a61e3d (diff)
downloadouroboros-99d19307fae8f1370f52a62aee88fded624ad464.tar.gz
ouroboros-99d19307fae8f1370f52a62aee88fded624ad464.zip
lib, irmd, ipcpd: Change pid to api
Changes the variable name as well to API instead of PID.
Diffstat (limited to 'src/ipcpd/ipcp.c')
-rw-r--r--src/ipcpd/ipcp.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/ipcpd/ipcp.c b/src/ipcpd/ipcp.c
index 54d1fad3..4acbffa2 100644
--- a/src/ipcpd/ipcp.c
+++ b/src/ipcpd/ipcp.c
@@ -50,7 +50,7 @@ int ipcp_arg_check(int argc, char * argv[])
if (argc != 2)
return -1;
/* argument 1: pid of irmd */
if (atoi(argv[1]) == 0)
return -1;
@@ -203,7 +203,7 @@ void * ipcp_main_loop(void * o)
}
ret_msg.has_result = true;
ret_msg.result =
- _ipcp->ops->ipcp_flow_alloc(msg->pid,
+ _ipcp->ops->ipcp_flow_alloc(msg->api,
msg->port_id,
msg->dst_name,
msg->src_ae_name,
@@ -216,7 +216,7 @@ void * ipcp_main_loop(void * o)
}
ret_msg.has_result = true;
ret_msg.result =
- _ipcp->ops->ipcp_flow_alloc_resp(msg->pid,
+ _ipcp->ops->ipcp_flow_alloc_resp(msg->api,
msg->port_id,
msg->result);
break;
@@ -50,7 +50,7 @@ int ipcp_arg_check(int argc, char * argv[])
if (argc != 2)
return -1;
- /* argument 1: pid of irmd */
+ /* argument 1: api of irmd */
if (atoi(argv[1]) == 0)
return -1;